summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/uml.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/uml.h')
-rw-r--r--umbrello/umbrello/uml.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/umbrello/umbrello/uml.h b/umbrello/umbrello/uml.h
index 93cd981e..b2f9181d 100644
--- a/umbrello/umbrello/uml.h
+++ b/umbrello/umbrello/uml.h
@@ -82,7 +82,7 @@ public:
/**
* Constructor. Calls all init functions to create the application.
*/
- UMLApp(TQWidget* tqparent=0, const char* name=0);
+ UMLApp(TQWidget* parent=0, const char* name=0);
/**
* Standard deconstructor.
@@ -247,7 +247,7 @@ public:
void setDiagramMenuItemsState(bool bState);
/**
* Returns the widget used as the tqparent for UMLViews.
* @return The main view widget.
*/
TQWidget* getMainViewWidget();
@@ -984,13 +984,13 @@ private:
bool m_loading;
/**
* Shows, and is tqparent of, all the UMLViews (diagrams)
* if tabbed diagrams are not enabled.
*/
TQWidgetStack* m_viewStack;
/**
* Shows, and is tqparent of, all the UMLViews (diagrams)
* if tabbed diagrams are enabled.
*/
KTabWidget* m_tabWidget;
@@ -247,7 +247,7 @@ public:
void setDiagramMenuItemsState(bool bState);
/**
- * Returns the widget used as the tqparent for UMLViews.
+ * Returns the widget used as the parent for UMLViews.
* @return The main view widget.
*/
@@ -984,13 +984,13 @@ private:
bool m_loading;
/**
- * Shows, and is tqparent of, all the UMLViews (diagrams)
+ * Shows, and is parent of, all the UMLViews (diagrams)
* if tabbed diagrams are not enabled.
*/
@@ -984,13 +984,13 @@ private:
TQWidgetStack* m_viewStack;
/**
- * Shows, and is tqparent of, all the UMLViews (diagrams)
+ * Shows, and is parent of, all the UMLViews (diagrams)
* if tabbed diagrams are enabled.
*/